var group___o_t_h_e_rauxiliary =
[
    [ "double", "d8/d9b/group__double_o_t_h_e_rauxiliary.html", "d8/d9b/group__double_o_t_h_e_rauxiliary" ],
    [ "real", "d1/db5/group__real_o_t_h_e_rauxiliary.html", "d1/db5/group__real_o_t_h_e_rauxiliary" ],
    [ "complex", "d4/db0/group__complex_o_t_h_e_rauxiliary.html", "d4/db0/group__complex_o_t_h_e_rauxiliary" ],
    [ "complex16", "d0/d50/group__complex16_o_t_h_e_rauxiliary.html", "d0/d50/group__complex16_o_t_h_e_rauxiliary" ],
    [ "clartg", "df/dd1/group___o_t_h_e_rauxiliary_ga45afd4405cf6da478ce4de9576303369.html#ga45afd4405cf6da478ce4de9576303369", null ],
    [ "classq", "df/dd1/group___o_t_h_e_rauxiliary_gad00e3fc7bc325256b1115351098ebfc6.html#gad00e3fc7bc325256b1115351098ebfc6", null ],
    [ "disnan", "df/dd1/group___o_t_h_e_rauxiliary_ga230d4e1886896853b11e44e541b2c6a3.html#ga230d4e1886896853b11e44e541b2c6a3", null ],
    [ "dlabad", "df/dd1/group___o_t_h_e_rauxiliary_ga57ac7409aedb2a380d5d0e625ffbeb7a.html#ga57ac7409aedb2a380d5d0e625ffbeb7a", null ],
    [ "dlacpy", "df/dd1/group___o_t_h_e_rauxiliary_ga7eb8731ffab2734378157c40964bf788.html#ga7eb8731ffab2734378157c40964bf788", null ],
    [ "dlae2", "df/dd1/group___o_t_h_e_rauxiliary_ga8a36d905c1c66d345f791b91254da0ae.html#ga8a36d905c1c66d345f791b91254da0ae", null ],
    [ "dlaebz", "df/dd1/group___o_t_h_e_rauxiliary_ga79da86f5a84d0038788717338eef245d.html#ga79da86f5a84d0038788717338eef245d", null ],
    [ "dlaev2", "df/dd1/group___o_t_h_e_rauxiliary_ga404759a75990a78660c741b3448b27e8.html#ga404759a75990a78660c741b3448b27e8", null ],
    [ "dlagts", "df/dd1/group___o_t_h_e_rauxiliary_ga0fbc9a87ffa4a60adadcb4fc511c2556.html#ga0fbc9a87ffa4a60adadcb4fc511c2556", null ],
    [ "dlaisnan", "df/dd1/group___o_t_h_e_rauxiliary_ga341ec834c6fc14a17fead550ff486022.html#ga341ec834c6fc14a17fead550ff486022", null ],
    [ "dlaneg", "df/dd1/group___o_t_h_e_rauxiliary_ga4932b5966e6a63f7d7b9f0a189003b6e.html#ga4932b5966e6a63f7d7b9f0a189003b6e", null ],
    [ "dlanst", "df/dd1/group___o_t_h_e_rauxiliary_ga2d199841a9ffcf46d31e13e326d195dc.html#ga2d199841a9ffcf46d31e13e326d195dc", null ],
    [ "dlapy2", "df/dd1/group___o_t_h_e_rauxiliary_gacf4c47c2f593fb3a4e842bca6df1240b.html#gacf4c47c2f593fb3a4e842bca6df1240b", null ],
    [ "dlapy3", "df/dd1/group___o_t_h_e_rauxiliary_gad929930f6e7780e8a1d73b2515ddd42b.html#gad929930f6e7780e8a1d73b2515ddd42b", null ],
    [ "dlarnv", "df/dd1/group___o_t_h_e_rauxiliary_ga77e05a87ced667cbdb502aa87c72d056.html#ga77e05a87ced667cbdb502aa87c72d056", null ],
    [ "dlarra", "df/dd1/group___o_t_h_e_rauxiliary_ga0b5719c25a81a95270cd36178e283166.html#ga0b5719c25a81a95270cd36178e283166", null ],
    [ "dlarrb", "df/dd1/group___o_t_h_e_rauxiliary_gab3446b2d3189e23e5b95f18ea97b0a22.html#gab3446b2d3189e23e5b95f18ea97b0a22", null ],
    [ "dlarrc", "df/dd1/group___o_t_h_e_rauxiliary_gac6a65096bc8be9a4dc881a96147075ea.html#gac6a65096bc8be9a4dc881a96147075ea", null ],
    [ "dlarrd", "df/dd1/group___o_t_h_e_rauxiliary_gaa9fa3671522ed0e21695769fd85982c7.html#gaa9fa3671522ed0e21695769fd85982c7", null ],
    [ "dlarre", "df/dd1/group___o_t_h_e_rauxiliary_gae8358ae1847bb9cfb96b56b6f3ef6386.html#gae8358ae1847bb9cfb96b56b6f3ef6386", null ],
    [ "dlarrf", "df/dd1/group___o_t_h_e_rauxiliary_ga6fa2f60646088821e40fbe04a41aa7b1.html#ga6fa2f60646088821e40fbe04a41aa7b1", null ],
    [ "dlarrj", "df/dd1/group___o_t_h_e_rauxiliary_ga7cdb25c9766674132d73bcbba824ab31.html#ga7cdb25c9766674132d73bcbba824ab31", null ],
    [ "dlarrk", "df/dd1/group___o_t_h_e_rauxiliary_gad321b234af8d1ac9fbb18ca95a1c13f2.html#gad321b234af8d1ac9fbb18ca95a1c13f2", null ],
    [ "dlarrr", "df/dd1/group___o_t_h_e_rauxiliary_gafe58120dedcb8d85c7a689c2d822f4a6.html#gafe58120dedcb8d85c7a689c2d822f4a6", null ],
    [ "dlartg", "df/dd1/group___o_t_h_e_rauxiliary_ga86f8f877eaea0386cdc2c3c175d9ea88.html#ga86f8f877eaea0386cdc2c3c175d9ea88", null ],
    [ "dlartgp", "df/dd1/group___o_t_h_e_rauxiliary_gac216c77dadbc793b5f0697555af0775b.html#gac216c77dadbc793b5f0697555af0775b", null ],
    [ "dlaruv", "df/dd1/group___o_t_h_e_rauxiliary_ga55e7c02e398f2c6365c956d272836a89.html#ga55e7c02e398f2c6365c956d272836a89", null ],
    [ "dlas2", "df/dd1/group___o_t_h_e_rauxiliary_ga307400bc17cbe31b5b8827a2802efae4.html#ga307400bc17cbe31b5b8827a2802efae4", null ],
    [ "dlascl", "df/dd1/group___o_t_h_e_rauxiliary_ga7bce4c35ec5a86ee0bfdd15c476d99c8.html#ga7bce4c35ec5a86ee0bfdd15c476d99c8", null ],
    [ "dlasd0", "df/dd1/group___o_t_h_e_rauxiliary_gae17e31eb66deb0c5111275edbd302758.html#gae17e31eb66deb0c5111275edbd302758", null ],
    [ "dlasd1", "df/dd1/group___o_t_h_e_rauxiliary_gae73e96812a1bfc42d43c9697971c82a6.html#gae73e96812a1bfc42d43c9697971c82a6", null ],
    [ "dlasd2", "df/dd1/group___o_t_h_e_rauxiliary_ga32db876aadda88c12c75db105fe4f21c.html#ga32db876aadda88c12c75db105fe4f21c", null ],
    [ "dlasd3", "df/dd1/group___o_t_h_e_rauxiliary_ga791d0eee86fc85a3e132e613c55d1d56.html#ga791d0eee86fc85a3e132e613c55d1d56", null ],
    [ "dlasd4", "df/dd1/group___o_t_h_e_rauxiliary_gaf0ba74a3731059f524f3bdb703fd6fb4.html#gaf0ba74a3731059f524f3bdb703fd6fb4", null ],
    [ "dlasd5", "df/dd1/group___o_t_h_e_rauxiliary_gac354f735ef3e53f9ca32242d2db96f74.html#gac354f735ef3e53f9ca32242d2db96f74", null ],
    [ "dlasd6", "df/dd1/group___o_t_h_e_rauxiliary_ga0e070b3e60c4a799927b934a17031fba.html#ga0e070b3e60c4a799927b934a17031fba", null ],
    [ "dlasd7", "df/dd1/group___o_t_h_e_rauxiliary_ga5ec18a9b77aca48cfc490ad5022eeafe.html#ga5ec18a9b77aca48cfc490ad5022eeafe", null ],
    [ "dlasd8", "df/dd1/group___o_t_h_e_rauxiliary_gab80712d01afa9bb687bf87f10d0d2147.html#gab80712d01afa9bb687bf87f10d0d2147", null ],
    [ "dlasda", "df/dd1/group___o_t_h_e_rauxiliary_gaf8abcba620b2d5a1321889fd86cb3f12.html#gaf8abcba620b2d5a1321889fd86cb3f12", null ],
    [ "dlasdq", "df/dd1/group___o_t_h_e_rauxiliary_gafc8e49b5fff31027da26e1856f8a9b25.html#gafc8e49b5fff31027da26e1856f8a9b25", null ],
    [ "dlasdt", "df/dd1/group___o_t_h_e_rauxiliary_gab7d5a1edccc56fb53970dd9607fcd5ee.html#gab7d5a1edccc56fb53970dd9607fcd5ee", null ],
    [ "dlaset", "df/dd1/group___o_t_h_e_rauxiliary_ga89e332374c7cd87e5db54bfe21550bc3.html#ga89e332374c7cd87e5db54bfe21550bc3", null ],
    [ "dlasr", "df/dd1/group___o_t_h_e_rauxiliary_gaa0a984d2062d62286a7a78ed3ba06fda.html#gaa0a984d2062d62286a7a78ed3ba06fda", null ],
    [ "dlassq", "df/dd1/group___o_t_h_e_rauxiliary_ga30a35e8bdc75b593ecc6c679a649ffdd.html#ga30a35e8bdc75b593ecc6c679a649ffdd", null ],
    [ "dlasv2", "df/dd1/group___o_t_h_e_rauxiliary_gaee8e05a707783a9fba5d213093453543.html#gaee8e05a707783a9fba5d213093453543", null ],
    [ "ieeeck", "df/dd1/group___o_t_h_e_rauxiliary_ga97715c995b884378afbbff7915d884c5.html#ga97715c995b884378afbbff7915d884c5", null ],
    [ "iladlc", "df/dd1/group___o_t_h_e_rauxiliary_gab8b3783390380038c9d26de61d7aefb4.html#gab8b3783390380038c9d26de61d7aefb4", null ],
    [ "iladlr", "df/dd1/group___o_t_h_e_rauxiliary_gac0eeaff271e43cd10d066ef1cceb5f3b.html#gac0eeaff271e43cd10d066ef1cceb5f3b", null ],
    [ "ilaenv", "df/dd1/group___o_t_h_e_rauxiliary_gab1f37bde76d31aee91a09bb2f8e87ce6.html#gab1f37bde76d31aee91a09bb2f8e87ce6", null ],
    [ "ilaenv2stage", "df/dd1/group___o_t_h_e_rauxiliary_ga5703a2c3b32069742575eb5a8e89abee.html#ga5703a2c3b32069742575eb5a8e89abee", null ],
    [ "iparmq", "df/dd1/group___o_t_h_e_rauxiliary_ga6e703cb600283f4bcb1b340cfd8ad3d9.html#ga6e703cb600283f4bcb1b340cfd8ad3d9", null ],
    [ "lsamen", "df/dd1/group___o_t_h_e_rauxiliary_ga0b496168bf04278e5e57050403c150aa.html#ga0b496168bf04278e5e57050403c150aa", null ],
    [ "sisnan", "df/dd1/group___o_t_h_e_rauxiliary_gaeca6bb0411af000e3c883ee744184991.html#gaeca6bb0411af000e3c883ee744184991", null ],
    [ "slabad", "df/dd1/group___o_t_h_e_rauxiliary_ga117e4564430a16335ad47054c447cb79.html#ga117e4564430a16335ad47054c447cb79", null ],
    [ "slacpy", "df/dd1/group___o_t_h_e_rauxiliary_ga7780c991533ce8dd1f2c22ae2d563f08.html#ga7780c991533ce8dd1f2c22ae2d563f08", null ],
    [ "slae2", "df/dd1/group___o_t_h_e_rauxiliary_gaec32dea47a14590934b8970b078b58fd.html#gaec32dea47a14590934b8970b078b58fd", null ],
    [ "slaebz", "df/dd1/group___o_t_h_e_rauxiliary_ga4f5045e3ec268a759d36fec562d6e481.html#ga4f5045e3ec268a759d36fec562d6e481", null ],
    [ "slaev2", "df/dd1/group___o_t_h_e_rauxiliary_gaf79f0bb1a07a9d96b827eba946ec79fa.html#gaf79f0bb1a07a9d96b827eba946ec79fa", null ],
    [ "slag2d", "df/dd1/group___o_t_h_e_rauxiliary_gac8ea5cb7fd597f6b5ae9cade02d122b3.html#gac8ea5cb7fd597f6b5ae9cade02d122b3", null ],
    [ "slagts", "df/dd1/group___o_t_h_e_rauxiliary_gae4b431608960457e61e885f3a2e2b18e.html#gae4b431608960457e61e885f3a2e2b18e", null ],
    [ "slaisnan", "df/dd1/group___o_t_h_e_rauxiliary_ga9b6a1036554ed9b7196c641174d6a6da.html#ga9b6a1036554ed9b7196c641174d6a6da", null ],
    [ "slaneg", "df/dd1/group___o_t_h_e_rauxiliary_ga7ea5fb550bbab683a539b551e3496bcc.html#ga7ea5fb550bbab683a539b551e3496bcc", null ],
    [ "slanst", "df/dd1/group___o_t_h_e_rauxiliary_ga3f856bc9099be84550d6c98ed9a3c810.html#ga3f856bc9099be84550d6c98ed9a3c810", null ],
    [ "slapy2", "df/dd1/group___o_t_h_e_rauxiliary_gabfcdad5f1d5d0193f7285e018824aa66.html#gabfcdad5f1d5d0193f7285e018824aa66", null ],
    [ "slapy3", "df/dd1/group___o_t_h_e_rauxiliary_gadab147cb12ea8d677598a5aad10f7e4c.html#gadab147cb12ea8d677598a5aad10f7e4c", null ],
    [ "slarnv", "df/dd1/group___o_t_h_e_rauxiliary_ga379b09e3d4e7635db614d3b3973db5e7.html#ga379b09e3d4e7635db614d3b3973db5e7", null ],
    [ "slarra", "df/dd1/group___o_t_h_e_rauxiliary_ga4f440e7139c504926241c9f7f71332d2.html#ga4f440e7139c504926241c9f7f71332d2", null ],
    [ "slarrb", "df/dd1/group___o_t_h_e_rauxiliary_gad29562cff63b75a1f3f40e7f83aea2b7.html#gad29562cff63b75a1f3f40e7f83aea2b7", null ],
    [ "slarrc", "df/dd1/group___o_t_h_e_rauxiliary_ga3895a010b624d4185e3c0c60b3cf1196.html#ga3895a010b624d4185e3c0c60b3cf1196", null ],
    [ "slarrd", "df/dd1/group___o_t_h_e_rauxiliary_ga137b773fc78098f8177b09e7d6dc3c91.html#ga137b773fc78098f8177b09e7d6dc3c91", null ],
    [ "slarre", "df/dd1/group___o_t_h_e_rauxiliary_ga4a2b9dcf8e9c8f368fb6d39506781f46.html#ga4a2b9dcf8e9c8f368fb6d39506781f46", null ],
    [ "slarrf", "df/dd1/group___o_t_h_e_rauxiliary_gaaf557670fb7f0616fb74b6af8cae353b.html#gaaf557670fb7f0616fb74b6af8cae353b", null ],
    [ "slarrj", "df/dd1/group___o_t_h_e_rauxiliary_ga86d0ea9b6f2d76876a8f0c0e1a12868c.html#ga86d0ea9b6f2d76876a8f0c0e1a12868c", null ],
    [ "slarrk", "df/dd1/group___o_t_h_e_rauxiliary_gac34836aa49da0ba1ef397af5a5590e22.html#gac34836aa49da0ba1ef397af5a5590e22", null ],
    [ "slarrr", "df/dd1/group___o_t_h_e_rauxiliary_ga37c1c1075019c75d8975e952a09516d5.html#ga37c1c1075019c75d8975e952a09516d5", null ],
    [ "slartg", "df/dd1/group___o_t_h_e_rauxiliary_ga8836d25697ed4d8cc0b7d0f45b558c3b.html#ga8836d25697ed4d8cc0b7d0f45b558c3b", null ],
    [ "slartgp", "df/dd1/group___o_t_h_e_rauxiliary_gaf196d96b7826d09326521d4a30b4bca4.html#gaf196d96b7826d09326521d4a30b4bca4", null ],
    [ "slaruv", "df/dd1/group___o_t_h_e_rauxiliary_ga5ca61f3556928fc2698683460395d96c.html#ga5ca61f3556928fc2698683460395d96c", null ],
    [ "slas2", "df/dd1/group___o_t_h_e_rauxiliary_ga7047efd8096db5f0724f79cad80e4127.html#ga7047efd8096db5f0724f79cad80e4127", null ],
    [ "slascl", "df/dd1/group___o_t_h_e_rauxiliary_ga11e6ce67ce97ca5b0a3a7bc5645a09d9.html#ga11e6ce67ce97ca5b0a3a7bc5645a09d9", null ],
    [ "slasd0", "df/dd1/group___o_t_h_e_rauxiliary_ga7a8da896f51f0ce43896b61efa3d0381.html#ga7a8da896f51f0ce43896b61efa3d0381", null ],
    [ "slasd1", "df/dd1/group___o_t_h_e_rauxiliary_ga882db55a5643e6b13ebbf68635f3946c.html#ga882db55a5643e6b13ebbf68635f3946c", null ],
    [ "slasd2", "df/dd1/group___o_t_h_e_rauxiliary_ga33ea099005fc608ad8a5b79662e02b84.html#ga33ea099005fc608ad8a5b79662e02b84", null ],
    [ "slasd3", "df/dd1/group___o_t_h_e_rauxiliary_ga4359e33241fa45b40ca5b25e6bee9054.html#ga4359e33241fa45b40ca5b25e6bee9054", null ],
    [ "slasd4", "df/dd1/group___o_t_h_e_rauxiliary_ga6680aa4ad62702cd9a00d7530c8ab53a.html#ga6680aa4ad62702cd9a00d7530c8ab53a", null ],
    [ "slasd5", "df/dd1/group___o_t_h_e_rauxiliary_ga19de62ad22e8492c93ac450198557d05.html#ga19de62ad22e8492c93ac450198557d05", null ],
    [ "slasd6", "df/dd1/group___o_t_h_e_rauxiliary_ga49655eb79b1745feabd7e9069f05e485.html#ga49655eb79b1745feabd7e9069f05e485", null ],
    [ "slasd7", "df/dd1/group___o_t_h_e_rauxiliary_ga506889eb5029bb8325b9b2ac02a62bce.html#ga506889eb5029bb8325b9b2ac02a62bce", null ],
    [ "slasd8", "df/dd1/group___o_t_h_e_rauxiliary_gac4e0b8da65a5d9493e17f46cd010e6cc.html#gac4e0b8da65a5d9493e17f46cd010e6cc", null ],
    [ "slasda", "df/dd1/group___o_t_h_e_rauxiliary_gafe52aa918bfa2a863f122f39ae9e6404.html#gafe52aa918bfa2a863f122f39ae9e6404", null ],
    [ "slasdq", "df/dd1/group___o_t_h_e_rauxiliary_gabb4a455a53f317631c56b07d4828eb28.html#gabb4a455a53f317631c56b07d4828eb28", null ],
    [ "slasdt", "df/dd1/group___o_t_h_e_rauxiliary_gae747f83ac11f2283d1d3f8b09d7a1138.html#gae747f83ac11f2283d1d3f8b09d7a1138", null ],
    [ "slaset", "df/dd1/group___o_t_h_e_rauxiliary_ga6174184453f17ad7cc3488044325d5ac.html#ga6174184453f17ad7cc3488044325d5ac", null ],
    [ "slasr", "df/dd1/group___o_t_h_e_rauxiliary_ga60f6d566e3a36c43835b0ff3055879dc.html#ga60f6d566e3a36c43835b0ff3055879dc", null ],
    [ "slassq", "df/dd1/group___o_t_h_e_rauxiliary_ga0b3fba7d81ada1035f0cc314b83da433.html#ga0b3fba7d81ada1035f0cc314b83da433", null ],
    [ "slasv2", "df/dd1/group___o_t_h_e_rauxiliary_ga8783434fbc24d465134e5604c5737565.html#ga8783434fbc24d465134e5604c5737565", null ],
    [ "xerbla", "df/dd1/group___o_t_h_e_rauxiliary_ga377ee61015baf8dea7770b3a404b1c07.html#ga377ee61015baf8dea7770b3a404b1c07", null ],
    [ "xerbla_array", "df/dd1/group___o_t_h_e_rauxiliary_ga45f1b23f68dd586f20299b80d1c9288d.html#ga45f1b23f68dd586f20299b80d1c9288d", null ],
    [ "zlartg", "df/dd1/group___o_t_h_e_rauxiliary_ga1e266e78a9a8585a1fc67f2d23badc64.html#ga1e266e78a9a8585a1fc67f2d23badc64", null ],
    [ "zlassq", "df/dd1/group___o_t_h_e_rauxiliary_ga68e6df2a795d699a2c4d61ebab6828d6.html#ga68e6df2a795d699a2c4d61ebab6828d6", null ]
];